# Using Reports
### On this page
  * [Accessing Report](https://help.sap.com/docs/leanix/ea/using-reports#accessing-report)
  * [Using Report](https://help.sap.com/docs/leanix/ea/using-reports#using-report)
  * [Apply Filter](https://help.sap.com/docs/leanix/ea/using-reports#apply-filter)
  * [Apply View](https://help.sap.com/docs/leanix/ea/using-reports#apply-view)
  * [Clustering](https://help.sap.com/docs/leanix/ea/using-reports#clustering)
  * [Report-specific configuration](https://help.sap.com/docs/leanix/ea/using-reports#report-specific-configuration)
  * [Side Panel](https://help.sap.com/docs/leanix/ea/using-reports#side-panel)
  * [Creating a New Report](https://help.sap.com/docs/leanix/ea/using-reports#creating-a-new-report)


View all
Using reports in SAP LeanIX is a straightforward process that can provide valuable insights and analytics on your organization's IT landscape. Here are the steps to create, customize, and use reports in SAP LeanIX:
